@@ -14,7 +14,7 @@ STOPPED = "STOPPED"
 TASK_DONE_LIST = (FAILURE, COMPLETE, STOPPED)
 
 bar_suffix = NEURO_AI_STR + " {desc}: {percentage:.1f}%|{bar}| remaining: {remaining} || elapsed: {elapsed} "
-dash_str = "Started {0}. View status at https://dashboard.neuro-ai.co.uk/task?id={1}"
+dash_str = "Started {0}. View status at https://dashboard.getneuro.ai/task?id={1}"
 one_hundred_percent = 100
 
 
@@ -51,7 +51,8 @@ class Task:
             if self.task_state == FAILURE:
                 self.update(include_result=True)
                 npu_print(f"Error for task {self.task_id}: {self.task_result}", level="ERROR")
-                exit(1)
+                raise Exception
+                # exit(1)
             if self.task_state == STOPPED:
                 npu_print("Task has been stopped.")
                 return
