@@ -1,5 +1,5 @@
 from .compile import compile
-from .common import checkData as upload_data
+from .common import check_data as upload_data
 from .predict import predict
 from .train import train
 from .common import api
