@@ -187,7 +187,7 @@ def check_data(data, name=""):
             hub_meta = base64.b64encode(dill.dumps(hub_meta)).decode()
             return HubDataset(hub_meta)
     except Exception as e:
-        print(e)
+        # print(e)
         pass
     if isinstance(data, str) and (data.endswith(("npy", "npz")) or ObjectId.is_valid(data) or data == ""):
         return data
@@ -390,6 +390,7 @@ def make_request(request_type_function, url, data, headers, json, params, **kwar
             npu_print(f"Error: {response['error']}", level="ERROR")
         elif "message" in response:
             npu_print(f"Error: {response['message']}", level="ERROR")
+        raise Exception
     # exit(1)
 
 
